IkeV2Platform class abstract

Inheritance
  • Object
  • PlatformInterface
  • IkeV2Platform
Implementers

Constructors

IkeV2Platform()
Constructs a IkeV2Platform.

Properties

charonErrorState → Future<CharonErrorState?>
Get current error state from VpnStateService. (Android only) When IkeV2State.error is received, details of error can be inspected by CharonErrorState. Returns null on non-android platform.
no setter
currentState → Future<IkeV2State>
Get current state.
no setter
hashCode → int
The hash code for this object.
no setterinherited
onStateChanged → Stream<IkeV2State>
Receive state change from VPN service.
no setter
onTrafficChanged → Stream<VpnTrafficStats>
Receive traffic stats from VPN service (Android only).
no setter
prepared → Future<bool>
Check if vpn connection has been prepared. (Android only)
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connectIkev2EAP({required String server, required String username, required String password, String? name, int? mtu, int? port, String? remoteId, String? localId, bool disableCertValidation = false}) → Future<void>
Connect to VPN. (IKEv2-EAP)
connectIkev2Psk({required String server, required String username, required String password, required String remoteId, required String localId, String? name, int? mtu, int? port}) → Future<void>
Connect to VPN. (IKEv2-PSK)
connectIPSec({required String server, required String username, required String password, required String secret, String? name, int? mtu, int? port}) → Future<void>
Connect to VPN. (IPSec)
disconnect() → Future<void>
Disconnect and stop VPN service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepare() → Future<bool>
Prepare for vpn connection. (Android only)
startTrafficMonitor() → Future<void>
Start monitoring VPN traffic (Android only).
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ IkeV2Platform
The default instance of IkeV2Platform to use.
getter/setter pair