VpnTrafficStats class

Constructors

VpnTrafficStats({required int uploadSpeed, required int downloadSpeed, required int totalUpload, required int totalDownload, required int duration})
VpnTrafficStats.fromMap(Map map)
factory

Properties

downloadSpeed int
final
duration int
final
formattedDuration String
🕒 Returns duration in HH:mm:ss format
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalDownload int
final
totalUpload int
final
uploadSpeed int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited